<?php
/*
 * Exim.php - Exim driver for Mail_BSMTP
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package Mail_BSMTP
 * @author Tim Jackson <tim@timj.co.uk>
 * @copyright (c)2002-2008 Tim Jackson
 * @license LGPLv3
 * 
 */

require_once 'Mail/BSMTP/Driver.php';

class Mail_BSMTP_Driver_Exim extends Mail_BSMTP_Driver
{
	protected $_options = array('exim_bin_path' => '/usr/sbin/exim');
	
	/**
	 * Constructor. Valid options that can be passed are:
	 * exim_bin_path = path to the Exim binary. Defaults to /usr/sbin/exim
	 *
	 * @param  $options Options
	 */
	public function __constructor($options = array())
	{
		return parent::_constructor();
	}
	
	public function sendQueue($tmp_file)
	{
		$fp = fopen($tmp_file, 'r');
		if ($fp) {
			$proc_descriptor = array(
				0 => array('pipe', 'r'), // stdin
				1 => array('pipe', 'w'), // stdout
				2 => array('pipe', 'w'), // stderr
			);
			$command = $this->_options['exim_bin_path'] . ' -bS';
			$proc = proc_open($command, $proc_descriptor, $pipes);
			if (is_resource($proc)) {
				$cmd_output = '';
				while (!feof($fp)) {
					$line = fgets($fp);
					fputs($pipes[0], $line);
				}
				fclose($pipes[0]);
				
				// read from stdout
				while(!feof($pipes[1])) {
					$cmd_output .= fgets($pipes[1]);
				}
				fclose($pipes[1]);
				
				// read from stderr
				while(!feof($pipes[2])) {
					$cmd_output .= fgets($pipes[2]);
				}
				fclose($pipes[2]);
				
				$ret = proc_close($proc);
				if ($ret != 0) {
					throw new Exception("BSMTP error: status $ret, output: $cmd_output (command was: $command)");
					return false;
				} else if (!empty($cmd_output)) {
					throw new Exception("BSMTP warning: $cmd_output (command was: $command)");
					return false;
				}
			} else {
				throw new Exception('BSMTP error: could not open proc');
				return false;
			}
			fclose($fp);
		} else {
			throw new Exception("Could not open temp file $tmp_file for reading");
			return false;
		}
		return true;
	}
	
	public function validateAddress($address)
	{
		$command = $this->_options['exim_bin_path'] . ' -bt ' . escapeshellarg($address);
		exec($command, $out, $ret);
		if ($ret == 0) {
			return true;
		}
		return false;
	}
}
